@@ -106,11 +106,18 @@ class WebDataset(DataPipeline, FluidInterface):
         shardshuffle=None,
         cache_size=-1,
         cache_dir=None,
+        url_to_name=cache.pipe_cleaner,
         detshuffle=False,
         nodesplitter=shardlists.single_node_only,
         verbose=False,
     ):
         super().__init__()
+        cache_size = int(os.environ.get("WDS_CACHE_SIZE", cache_size))
+        cache_dir = os.environ.get("WDS_CACHE", cache_dir)
+        if cache_dir is not None:
+            cache_dir = os.path.expanduser(cache_dir)
+            if not os.path.exists(cache_dir):
+                raise ValueError(f"cache directory {cache_dir} does not exist")
         if isinstance(urls, IterableDataset):
             assert not resampled
             self.append(urls)
@@ -145,6 +152,7 @@ class WebDataset(DataPipeline, FluidInterface):
                 cache.cached_tarfile_to_samples(
                     handler=handler,
                     verbose=verbose,
+                    url_to_name=url_to_name,
                     cache_size=cache_size,
                     cache_dir=cache_dir,
                 )
