@@ -6,7 +6,12 @@
 
 """Classes and functions for writing tar files and WebDataset files."""
 
-import io, json, pickle, re, tarfile, time
+import io
+import json
+import pickle
+import re
+import tarfile
+import time
 from typing import Any, Callable, Optional, Union
 
 import numpy as np
@@ -30,9 +35,7 @@ def imageencoder(image: Any, format: str = "PNG"):  # skipcq: PYL-W0622
     if isinstance(image, np.ndarray):
         if image.dtype in [np.dtype("f"), np.dtype("d")]:
             if not (np.amin(image) > -0.001 and np.amax(image) < 1.001):
-                raise ValueError(
-                    f"image values out of range {np.amin(image)} {np.amax(image)}"
-                )
+                raise ValueError(f"image values out of range {np.amin(image)} {np.amax(image)}")
             image = np.clip(image, 0.0, 1.0)
             image = np.array(image * 255.0, "uint8")
         assert image.ndim in [2, 3]
@@ -139,9 +142,7 @@ def add_handlers(d, keys, value):
 def make_handlers():
     """Create a list of handlers for encoding data."""
     handlers = {}
-    add_handlers(
-        handlers, "cls cls2 class count index inx id", lambda x: str(x).encode("ascii")
-    )
+    add_handlers(handlers, "cls cls2 class count index inx id", lambda x: str(x).encode("ascii"))
     add_handlers(handlers, "txt text transcript", lambda x: x.encode("utf-8"))
     add_handlers(handlers, "html htm", lambda x: x.encode("utf-8"))
     add_handlers(handlers, "pyd pickle", pickle.dumps)
@@ -192,9 +193,7 @@ def encode_based_on_extension(sample: dict, handlers: dict):
     :param sample: data sample (a dict)
     :param handlers: handlers for encoding
     """
-    return {
-        k: encode_based_on_extension1(v, k, handlers) for k, v in list(sample.items())
-    }
+    return {k: encode_based_on_extension1(v, k, handlers) for k, v in list(sample.items())}
 
 
 def make_encoder(spec: Union[bool, str, dict, Callable]):
@@ -267,6 +266,7 @@ class TarWriter:
         compress: Optional[bool] = None,
         encoder: Union[None, bool, Callable] = True,
         keep_meta: bool = False,
+        mtime: Optional[float] = None,
         format: Any = None,
     ):
         """Create a tar writer.
@@ -278,8 +278,10 @@ class TarWriter:
         :param compress: desired compression
         :param encoder: encoder function
         :param keep_meta: keep metadata (entries starting with "_")
+        :param mtime: modification time (set this to some fixed value to get reproducible tar files)
         """
         format = getattr(tarfile, format, format) if format else tarfile.USTAR_FORMAT
+        self.mtime = mtime
         if isinstance(fileobj, str):
             if compress is False:
                 tarmode = "w|"
@@ -332,9 +334,7 @@ class TarWriter:
             if k[0] == "_":
                 continue
             if not isinstance(v, (bytes, bytearray, memoryview)):
-                raise ValueError(
-                    f"{k} doesn't map to a bytes after encoding ({type(v)})"
-                )
+                raise ValueError(f"{k} doesn't map to a bytes after encoding ({type(v)})")
         key = obj["__key__"]
         for k in sorted(obj.keys()):
             if k == "__key__":
@@ -347,7 +347,7 @@ class TarWriter:
             now = time.time()
             ti = tarfile.TarInfo(key + "." + k)
             ti.size = len(v)
-            ti.mtime = now
+            ti.mtime = self.mtime if self.mtime is not None else now
             ti.mode = self.mode
             ti.uname = self.user
             ti.gname = self.group
@@ -416,11 +416,7 @@ class ShardWriter:
 
         :param obj: sample to be written
         """
-        if (
-            self.tarstream is None
-            or self.count >= self.maxcount
-            or self.size >= self.maxsize
-        ):
+        if self.tarstream is None or self.count >= self.maxcount or self.size >= self.maxsize:
             self.next_stream()
         size = self.tarstream.write(obj)
         self.count += 1
